eval

package
v0.0.0-...-8fd365b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 25, 2018 License: GPL-3.0 Imports: 8 Imported by: 0

Documentation

Overview

Package eval evaluates an expression provided in string form.

Index

Constants

const (
	UnbalancedParenthesesError evalError = iota
	MissingFactorError
	MissingArgumentError
	UnknownFunctionError
	TrailingTokensError
	UnknownError
)

Error values

Variables

This section is empty.

Functions

func Evaluate

func Evaluate(expression string) (expr.Expr, error)

Evaluate evaluates an expression provided in string form.

func NewLexer

func NewLexer(input io.Reader) (chan tokens.Token, error)

NewLexer creates a new lexer to read from the provided reader and returns the channel to which it writes.

Types

This section is empty.

Jump to